@@ -49,13 +49,14 @@
 package com.openexchange.user.copy.internal.folder.util;
 import java.util.HashSet;
 import java.util.Set;
+import java.util.TreeSet;
 
 /**
  * {@link Node}
  *
  * @author <a href="mailto:steffen.templin@open-xchange.com">Steffen Templin</a>
  */
-public class Node<T> {
+public class Node<T extends Comparable<T>> implements Comparable<Node<T>> {
 
     private final T value;
 
@@ -76,7 +77,7 @@ public class Node<T> {
     }
 
     public Set<Node<T>> getChildren() {
-        return new HashSet<Node<T>>(children);
+        return new TreeSet<>(children);
     }
 
     public void setChildren(final Set<Node<T>> children) {
@@ -164,4 +165,9 @@ public class Node<T> {
         return "{" + value.toString() + "}";
     }
 
+    @Override
+    public int compareTo(Node<T> o) {
+        return this.value.compareTo(o.getValue());
+    }
+
 }
